using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Schedule;
using Syncfusion.Schedule;
using Syncfusion.Windows.Forms.Grid;
using System.IO;

namespace SampleSchedule
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {

            ArrayListDataProvider scheduleProvider;
            string fileName = "default.XML";
            if (File.Exists(fileName))
            {
                scheduleProvider = ArrayListDataProvider.LoadXML(fileName);
                scheduleProvider.FileName = fileName;
                scheduleProvider.IsDirty = false;
            }
            else
            {
                scheduleProvider = new ArrayListDataProvider();
                scheduleProvider.MasterList = new ArrayListAppointmentList();
                scheduleProvider.FileName = "default.XML";
            }

          
            this.scheduleControl1.Calendar.DateValue = DateTime.Now;

            this.scheduleControl1.ScheduleType = ScheduleViewType.WorkWeek;//ScheduleViewType.Day;//.WorkWeek;//.Week;//ScheduleViewType.WorkWeek;// ScheduleViewType.Day;//.WorkWeek;
            //set the data source
            this.scheduleControl1.DataSource = scheduleProvider;
    
            //need to pass the schedule to the NavigationGrid so it can handle setting the calendar type in an override
            MyCalendarGrid grid = this.scheduleControl1.Calendar.CalenderGrid as MyCalendarGrid;
            if (grid != null)
            {
                grid.Schedule = this.scheduleControl1;
            }
        }



        private void button1_Click(object sender, EventArgs e)
        {
            scheduleControl1.Appearance.WorkWeekHeaderFormat = scheduleControl1.Appearance.WorkWeekHeaderFormat == "d" ? "yyyy.MM.dd" : "d";
        }
    }


    public class MyScheduleControl : ScheduleControl
    {

        public override NavigationCalendar CreateNavigationCalendar()
        {
            return new MyNavigationCalendar();
        }
    }

    public class MyNavigationCalendar : NavigationCalendar
    {
       
        public override Syncfusion.Windows.Forms.Grid.GridControl CreateCalendarGrid()
        {

            return new MyCalendarGrid();
        }
    }

    public class MyCalendarGrid : GridControl
    {
        ScheduleControl schedule;

        public ScheduleControl Schedule
        {
            get { return schedule; }
            set { schedule = value; }
        }
        
        int weekNumberIndent = 12;
        int rowsPerCal = 8;
        int buttonDX = 5;
        int buttonXOffset = 8;
        protected override void OnCellClick(GridCellClickEventArgs e)
        {
            int row, col;
			Point pt = this.PointToClient(Control.MousePosition);
            if (this.PointToRowCol(pt, out row, out col))
            {
                if (col == 1 && pt.X <= this.weekNumberIndent)  
                {
                    #region week click
                    if (row % rowsPerCal > 1)
                    {
                        e.Cancel = true;
                       if (schedule.ScheduleType != ScheduleViewType.WorkWeek)
                        {
                             schedule.Calendar.SelectedDates[0] = (DateTime)this[row, 2].CellValue;
                             schedule.GetScheduleHost().SwitchTo(ScheduleViewType.WorkWeek, true);
                        }
                       else
                        {
                            DateTime dt = (DateTime)this[row, 2].CellValue;
                            schedule.Calendar.DateValue = dt;
                            AdjustWorkWeekSelections();
                          //  schedule.Refresh();
                        }
                    }
                    #endregion
                }
                else if (row % rowsPerCal == 0 && (row > 0 || schedule.ScheduleType != ScheduleViewType.Month))
                {
                    #region Month Click...
                    if (row == 0)
                    {

                        if (e.MouseEventArgs.X < buttonXOffset + buttonDX + 4
                            || e.MouseEventArgs.X > this.ColWidths.GetTotal(0, this.ColCount) - buttonXOffset - buttonDX - 4)
                        {
                            return;//arrow click - skip code...
                        }
                        //drop thru...
                    }

                    //month click...
                    e.Cancel = true;
                   if (schedule.ScheduleType != ScheduleViewType.Month)
                    {
                        schedule.Calendar.DateValue = (DateTime)this[row + 4, 2].CellValue;
                        schedule.GetScheduleHost().SwitchTo(ScheduleViewType.Month, true);
                    }
                    else
                    {
                        int cal = e.RowIndex / rowsPerCal;
                        DateTime dt1 = schedule.Calendar.DateValue.AddMonths(cal);
                        dt1 = dt1.AddDays(-dt1.Day + 1);
                        schedule.Calendar.DateValue = dt1;
                    }
                    #endregion
                }
                
            }
            if(!e.Cancel)
                base.OnCellClick(e);
        }



        private void AdjustWorkWeekSelections()
        {
            int count = 5;
            schedule.Calendar.SelectedDates.BeginUpdate();
            DateTime theDate = schedule.Calendar.DateValue;
            if (theDate.DayOfWeek == DayOfWeek.Sunday)
                theDate = theDate.AddDays(1);//move to Monday
            theDate = theDate.AddDays(-(theDate.DayOfWeek - DayOfWeek.Monday));
            schedule.Calendar.SelectedDates.Clear();
            while (count > 0)
            {
                schedule.Calendar.SelectedDates.Add(theDate);
                theDate = theDate.AddDays(1);
                count--;
            }
            schedule.Calendar.SelectedDates.EndUpdate();
        }
    }


  
    
}